@@ -9,22 +9,33 @@ import pkgutil
 import subprocess
 
 platform = sys.platform
+target_platform = os.environ["target_platform"]
 py_major = sys.version_info[:2]
+pypy = "__pypy__" in sys.builtin_module_names
 
 loader = pkgutil.get_loader("terminado.tests")
 test_path = os.path.dirname(loader.path)
 pytest = [sys.executable, "-m", "pytest"]
-cov_args = ["--cov", "terminado"]
-pytest_args = ["-o", "junit_family=xunit2", "-vv", *cov_args, test_path]
+pytest_args = [test_path, "-vv"]
+
+if not pypy:
+    pytest_args += ["--cov", "terminado", "--no-cov-on-fail"]
+
 
 skips = []
 
 # flaky tests
 if platform != "linux":
-    skips += ["max_terminals", "single_process", "namespace", "basic_command"]
+    skips += [
+        "basic_command",
+        "max_terminals",
+        "namespace",
+        "single_process",
+        "unique_processes"
+    ]
 
-if platform == "darwin":
-    skips += ["unique_processes"]
+if "aarch64" in target_platform:
+    skips += ["max_terminals"]
 
 if not skips:
     print("all tests will be run", flush=True)
@@ -34,7 +45,7 @@ elif len(skips) == 1:
 else:
     pytest_args += ["-k", "not ({})".format(" or ".join(skips))]
 
-print("Final pytest args for", platform, py_major)
+print("Final pytest args for", platform, target_platform, py_major)
 print(" ".join([*pytest, *pytest_args]), flush=True)
 
 # actually run the tests
